<?php
/**
 * Theme functions
 *
 * @package droidpress
 * @since 3.0.0
 */

if ( ! function_exists( 'droidpress_setup' ) ) {
	/**
	 * Adds support for various theme features.
	 *
	 * @return void
	 */
	function droidpress_setup() {
		load_theme_textdomain( 'droidpress' );

		/*
		 * Adding Align wide support for Gutenberg
		 */
		add_theme_support( 'align-wide' );

		add_theme_support( 'automatic-feed-links' );
		add_theme_support( 'title-tag' );
		add_theme_support( 'post-thumbnails' );
		add_theme_support(
			'html5',
			array(
				'caption',
				'comment-form',
				'comment-list',
				'gallery',
				'search-form',
			)
		);
		add_theme_support(
			'custom-background',
			array(
				'default-color' => 'ffffff',
				'default-image' => '',
			)
		);
		add_theme_support(
			'custom-logo',
			array(
				'flex-height' => true,
				'flex-width'  => true,
				'header-text' => array( 'site-title', 'site-description' ),
				'height'      => 94,
				'width'       => 270,
			)
		);

		set_post_thumbnail_size( 1200, 800, true );

		register_nav_menus(
			array(
				'primary' => esc_html__( 'Primary Menu', 'droidpress' ),
				'footer'  => esc_html__( 'Footer Menu', 'droidpress' ),
			)
		);
	}
}
add_action( 'after_setup_theme', 'droidpress_setup' );

/**
 * Sets the content width for the theme.
 *
 * @return void
 */
function droidpress_content_width() {
	$GLOBALS['content_width'] = apply_filters( 'droidpress_content_width', 650 );
}
add_action( 'template_redirect', 'droidpress_content_width', 0 );

/**
 * Registers the theme widget areas.
 *
 * @return void
 */
function droidpress_sidebars() {
	register_sidebar(
		array(
			'id'            => 'sidebar',
			'description'   => esc_html__( 'Add sidebar widgets here.', 'droidpress' ),
			'name'          => esc_html__( 'Sidebar', 'droidpress' ),
			'before_widget' => '<section id="%1$s" class="%2$s widget">',
			'after_widget'  => '</section>',
			'before_title'  => '<h4 class="widget_title h3">',
			'after_title'   => '</h4>',
		)
	);

	register_sidebar(
		array(
			'id'            => 'footer',
			'description'   => esc_html__( 'Add footer widgets here.', 'droidpress' ),
			'name'          => esc_html__( 'Footer', 'droidpress' ),
			'before_widget' => '<div id="%1$s" class="%2$s widget col">',
			'after_widget'  => '</div>',
			'before_title'  => '<h4 class="widget-title">',
			'after_title'   => '</h4>',
		)
	);
}
add_action( 'widgets_init', 'droidpress_sidebars' );

/**
 * Enqueues the theme styles & scripts.
 *
 * @return void
 */
function droidpress_scripts() {
	wp_enqueue_style( 'droidpress-style', get_stylesheet_uri(), array(), '3.0.0' );
	wp_enqueue_style( 'droidpress-fonts', droidpress_get_fonts_url(), array(), '3.0.0' );

	wp_enqueue_script( 'droidpress-flexslider', get_template_directory_uri() . '/assets/js/jquery.flexslider-min.js', array( 'jquery' ), '2.7.1', true );
	wp_enqueue_script( 'droidpress-slider', get_template_directory_uri() . '/assets/js/slider.js', array( 'jquery' ), '2.7.1', true );
	wp_enqueue_script( 'droidpress-navigation', get_template_directory_uri() . '/assets/js/navigation.js', array(), '3.0.0', true );
	wp_enqueue_script( 'droidpress-skip-link-focus-fix', get_template_directory_uri() . '/assets/js/skip-link-focus-fix.js', array(), '3.0.0', true );
	if ( is_singular() && comments_open() && get_option( 'thread_comments' ) ) {
		wp_enqueue_script( 'comment-reply' );
	}
}
add_action( 'wp_enqueue_scripts', 'droidpress_scripts' );

/**
 * Returns the Google fonts URL used in the theme.
 *
 * @return string Google fonts URL
 */
function droidpress_get_fonts_url() {
	$font_families = apply_filters(
		'droidpress_font_families',
		array(
			'Poppins:400,700',
			'Roboto:300,300i,700,700i',
		)
	);

	$font_families[] = 'Inconsolata:400';

	$query_args = array(
		'family' => urlencode( implode( '|', $font_families ) ),
		'subset' => urlencode( 'latin,latin-ext' ),
	);

	$fonts_url = add_query_arg( $query_args, 'https://fonts.googleapis.com/css' );

	return esc_url_raw( $fonts_url );
}

/**
 * Include gutenberg functions.
 */
require_once get_template_directory() . '/inc/gutenberg.php';

/**
 * Include theme customizer.
 */
require_once get_template_directory() . '/inc/customizer/customizer.php';

/**
 * Include customizer custom styles.
 */
require_once get_template_directory() . '/inc/custom-styles.php';

/**
 * Include theme hooks.
 */
require_once get_template_directory() . '/inc/theme-hooks.php';

/**
 * Include theme tags.
 */
require_once get_template_directory() . '/inc/theme-tags.php';

/**
 * Require file to define tgmpa related class and functions
 */
require get_template_directory() . '/inc/functions-tgmpa.php';

/**
 * Include custom recent posts widget.
 */
require_once get_template_directory() . '/inc/lib/widgets/class-cc-recent-posts-widget.php';

/**
 * Include premium functions.
 */
if ( file_exists( get_template_directory() . '/inc/functions-premium.php' ) ) {
	require_once get_template_directory() . '/inc/functions-premium.php';
}
