<?php
/**
 * Outputs the customizer styles.
 *
 * @package droidpress
 * @since 3.0.0
 */

/**
 * Outputs the custom styles for the theme.
 *
 * @return void
 */
function droidpress_custom_color_styles() {
	$accent_color     = get_theme_mod( 'droidpress_colors_accent', '#dd971d' );
	$alt_accent_color = get_theme_mod( 'droidpress_colors_alt_accent', '#222b34' );

	$page_header_text_color = droidpress_get_contrast_text_color( '#' . get_background_color(), '#222222' );

	$custom_css = "
		a {
			border-bottom-color: {$accent_color};
			color: {$accent_color};
		}

		a:hover {
			border-bottom-color: {$alt_accent_color};
			color: {$alt_accent_color};
		}

		.btn,
		button,
		input[type=submit],
		input[type=button],
		.site-content .more-link,
		.comments-area .droidpress-cmt-reply a,
		.main-navigation .menu li.call-to-action a,
		.pagination .nav-links .page-numbers.current,
		.pagination .nav-links .page-numbers:hover,
		.pagination .nav-links .page-numbers:focus,
		.widget-area.sidebar .widget .tagcloud a:hover {
			background-color: {$accent_color};
			border-color: {$accent_color};
		}

		.btn:hover,
		button:hover,
		.site-content .more-link:hover,
		input[type=submit]:hover,
		input[type=button]:hover,
		.comments-area .droidpress-cmt-reply a:hover,
		.main-navigation .menu li.call-to-action a:hover {
			background-color: {$alt_accent_color};
			border-color: {$alt_accent_color};
		}

		.site-header a:hover,
		.hentry .entry-header a:hover,
		.hentry .entry-meta a:hover,
		.widget-area.sidebar .widget a:hover {
			color: {$accent_color};
		}

		.site-header-business .main-navigation,
		.site-header-blog .main-navigation {
			background-color: {$alt_accent_color};
		}

		.bypostauthor .comment-meta .avatar{
	   		border-color: {$accent_color};
	   	}

		.page-header,
		.page-template-elementor .entry-header {
			color: {$page_header_text_color};
		}

		@media ( min-width: 992px ) {
			.site-header-business .main-navigation .sub-menu a:hover,
			.site-header-blog .main-navigation .sub-menu a:hover {
				color: {$accent_color};
			}
		}
	";

	wp_add_inline_style( 'droidpress-style', $custom_css );
}
add_action( 'wp_enqueue_scripts', 'droidpress_custom_color_styles', 100 );

/**
 * Outputs the custom styles for the theme.
 *
 * @return void
 */
function droidpress_custom_typography_styles() {
	$fonts        = droidpress_get_selected_fonts();
	$body_font    = $fonts['body'];
	$heading_font = $fonts['heading'];

	$custom_css = "
		button,
		body,
		input,
		select,
		textarea {
			font-family: '{$body_font}', serif;
		}

		.h1, h1,
		.h2, h2,
		.h3, h3,
		.h4, h4,
		.h5, h5,
		.h6, h6,
		.btn,
		button,
		input[type=submit],
		input[type=button],
		.main-navigation,
		.comment-meta .fn,
		.site-footer,
		.hentry .entry-meta,
		.hentry .entry-meta a,
		.pagination .nav-links .page-numbers,
		.widget-area.sidebar .widget .cc_recent_post_item .cc_recent_post_item_content a{
			font-family: '{$heading_font}', serif;
		}
	";

	wp_add_inline_style( 'droidpress-style', $custom_css );
}
add_action( 'wp_enqueue_scripts', 'droidpress_custom_typography_styles', 100 );

/**
 * Adds custom classes to body for header/content layout.
 *
 * @param  array $classes The default body classes.
 * @return array          Body classes with custom classes added.
 */
function droidpress_custom_body_class( $classes ) {
	$full_width_header = get_theme_mod( 'droidpress_full_width_header', false );
	if ( $full_width_header ) {
		$classes[] = 'full-width-header';
	}

	$sidebar_layout = get_theme_mod( 'droidpress_sidebar_layout', 'default' );
	if ( 'default' !== $sidebar_layout ) {
		$classes[] = 'sidebar-layout-' . $sidebar_layout;
	}

	return $classes;
}
add_filter( 'body_class', 'droidpress_custom_body_class' );
