<?php
/**
 * Theme homepage options.
 *
 * @package droidpress
 * @since 3.0.0
 */

/**
 * Registers the customizer homepage options.
 *
 * @param  WP_Customize_Manager $wp_customize The WordPress customizer manager instance.
 * @return void
 */
function droidpress_customize_register_homepage( $wp_customize ) {
	/**
	 * == Homepage ==
	 *
	 * Add a homepage settings panel.
	 */
	$wp_customize->add_panel(
		'droidpress_home',
		array(
			'priority' => 120,
			'title'    => esc_html__( 'Homepage', 'droidpress' ),
		)
	);

	/**
	 * Move the homepage settings section to the homepage settings panel.
	 */
	$static_front_page_section        = $wp_customize->get_section( 'static_front_page' );
	$static_front_page_section->panel = 'droidpress_home';
	$static_front_page_section->title = esc_html__( 'Settings', 'droidpress' );
}
add_action( 'customize_register', 'droidpress_customize_register_homepage' );

/**
 * Checks if the current page is:
 * - the front page
 * - and has the free or premium homepage template.
 *
 * @return boolean true if the above criteria are met, otherwise false.
 */
function droidpress_is_homepage() {
	return is_front_page() && is_page_template( 'templates/homepage-premium.php' );
}

/**
 * Sanitizes the overlay opacity.
 *
 * @param int $value to return.
 * @return float The sanitized base line height.
 */
function droidpress_sanitize_opacity( $value ) {
	if ( ! abs( floatval( $value ) ) ) {
		$value = '0';
	}

	return $value;
}
