<?php
/**
 * This is CC Recent Post Widget File.
 *
 * @package droidpress
 * @since 1.0.0
 */

/**
 * CC Recent Post Widget Class.
 */
class CC_Recent_Posts_Widget extends WP_Widget {
	/**
	 * Constructor for CS_Recent_Posts_Widget.
	 */
	public function __construct() {
		parent::__construct(

			// Base ID of your widget.
			'cc_widget_recent_post',
			// Widget name will appear in UI.
			__( 'Thumbnail Recent Post', 'droidpress' ),
			// Widget description.
			array( 'description' => __( 'Thumbnail Recent Post Widgets', 'droidpress' ) )
		);
	}


	/**
	 * Creatng Widget Frontend
	 *
	 * @param  array $args  Array of Arguments.
	 * @param  array $instance Array of Instance.
	 * @return int Returns Zero
	 */
	public function widget( $args, $instance ) {
		$title = apply_filters( 'widget_title', $instance['title'] );

		$number = absint( $instance['number'] );

		$show_post_date = absint( $instance['show_date'] );

		if ( ! $number || empty( $number ) ) {
			$number = 3;
		}

		$r = new WP_Query(
			apply_filters(
				'widget_posts_args',
				array(
					'posts_per_page'      => $number,
					'no_found_rows'       => true,
					'post_status'         => 'publish',
					'ignore_sticky_posts' => true,
				)
			)
		);
		if ( $r->have_posts() ) :

			echo wp_kses_post( $args['before_widget'] );

			if ( ! empty( $title ) ) {
					echo wp_kses_post( $args['before_title'] . $title . $args['after_title'] );
			}
			?>
			<ul class="cc_recent_post_list">
				<?php
				while ( $r->have_posts() ) :
					$r->the_post();
					?>
					<li class="cc_recent_post_item">
						<?php
						if ( has_post_thumbnail() ) {
							?>
							<div class="cc_recent_post_item_image">
							<a href="<?php esc_url( the_permalink() ); ?>" title="<?php the_title(); ?>">
								<?php echo get_the_post_thumbnail( $r->ID, 'thumbnail' ); ?>
							</a>
						</div>
							<?php
						}
						?>
						<div class="cc_recent_post_item_content">
							<a href="<?php esc_url( the_permalink() ); ?>" title="<?php the_title(); ?>"><?php the_title(); ?></a>
							<?php
							if ( $show_post_date ) :
								?>
								<br />
								<?php
								the_time( 'd F Y' );
							endif;
							?>
						</div>
					</li>
				<?php endwhile; ?>
			</ul>
			<?php
			echo wp_kses_post( $args['after_widget'] );

			wp_reset_postdata();

		endif;
		return 0;
	}

	/**
	 * Widget Backend
	 *
	 * @param  array $instance Instance Array.
	 * @return int Returns Zero
	 */
	public function form( $instance ) {
		$title     = isset( $instance['title'] ) ? esc_attr( $instance['title'] ) : '';
		$number    = isset( $instance['number'] ) ? absint( $instance['number'] ) : 5;
		$show_date = isset( $instance['show_date'] ) ? (bool) $instance['show_date'] : false;
		?>
		<p><label for="<?php echo esc_attr( $this->get_field_id( 'title' ) ); ?>"><?php esc_html_e( 'Title:', 'droidpress' ); ?></label>
		<input class="widefat" id="<?php echo esc_attr( $this->get_field_id( 'title' ) ); ?>" name="<?php echo esc_attr( $this->get_field_name( 'title' ) ); ?>" type="text" value="<?php echo esc_attr( $title ); ?>" /></p>

		<p><label for="<?php echo esc_attr( $this->get_field_id( 'number' ) ); ?>"><?php esc_html_e( 'Number of posts to show:', 'droidpress' ); ?></label>
		<input class="tiny-text" id="<?php echo esc_attr( $this->get_field_id( 'number' ) ); ?>" name="<?php echo esc_attr( $this->get_field_name( 'number' ) ); ?>" type="number" step="1" min="1" value="<?php echo esc_attr( $number ); ?>" size="3" /></p>

		<p><input class="checkbox" type="checkbox"<?php checked( $show_date ); ?> id="<?php echo esc_attr( $this->get_field_id( 'show_date' ) ); ?>" name="<?php echo esc_attr( $this->get_field_name( 'show_date' ) ); ?>" />
		<label for="<?php echo esc_attr( $this->get_field_id( 'show_date' ) ); ?>"><?php esc_html_e( 'Display post date?', 'droidpress' ); ?></label></p>
		<?php
		return 0;
	}

	/**
	 * Updating widget replacing old instances with new.
	 *
	 * @param  array $new_instance New Instance.
	 * @param  array $old_instance Old Instance.
	 * @return array returns Updated Instance.
	 */
	public function update( $new_instance, $old_instance ) {
		$instance              = $old_instance;
		$instance['title']     = sanitize_text_field( $new_instance['title'] );
		$instance['number']    = (int) $new_instance['number'];
		$instance['show_date'] = isset( $new_instance['show_date'] ) ? (bool) $new_instance['show_date'] : false;
		return $instance;
	}
}



if ( ! function_exists( 'cc_register_recent_post_widgets' ) ) :

	/**
	 *  Register Widget Section
	 *
	 * The Function cc_register_recent_post_widgets Register Widget
	 *
	 * @return int Returns Zero
	 */
	function cc_register_recent_post_widgets() {
		register_widget( 'CC_Recent_Posts_Widget' );

		return 0;
	}

	add_action( 'widgets_init', 'cc_register_recent_post_widgets' );
endif;
?>
