<?php
/**
 * Theme hooks
 *
 * @package droidpress
 * @since 3.0.0
 */

/**
 * Add preconnect for Google Fonts.
 *
 * @param array  $urls           URLs to print for resource hints.
 * @param string $relation_type  The relation type the URLs are printed.
 * @return array $urls           URLs to print for resource hints.
 */
function droidpress_resource_hints( $urls, $relation_type ) {
	if ( wp_style_is( 'droidpress-fonts', 'queue' ) && 'preconnect' === $relation_type ) {
		$urls[] = array(
			'href' => 'https://fonts.gstatic.com',
			'crossorigin',
		);
	}

	return $urls;
}
add_filter( 'wp_resource_hints', 'droidpress_resource_hints', 10, 2 );

/**
 * Modifies the default excerpt length.
 *
 * @param  int $length The default excerpt length.
 * @return int         The modified excerpt length.
 */
function droidpress_excerpt_length( $length ) {
	if ( ! is_admin() ) {
		$length = get_theme_mod( 'droidpress_excerpt_length', 30 );
	}

	return $length;
}
add_filter( 'excerpt_length', 'droidpress_excerpt_length' );

/**
 * Modifies the default excerpt more markup.
 *
 * @param  string $more The default excerpt more markup.
 * @return string       The modified excerpt more markup.
 */
function droidpress_excerpt_more( $more ) {
	if ( ! is_admin() ) {
		$more = esc_html__( '&hellip;', 'droidpress' ) .
			sprintf( '<p><a href="%s" class="more-link">', esc_url( get_permalink() ) ) .
				get_theme_mod( 'droidpress_excerpt_more', esc_html__( 'Read more', 'droidpress' ) ) .
				'<span class="screen-reader-text">' .
					esc_html__( ' of ', 'droidpress' ) . esc_html( get_the_title() ) .
				'</span>' .
			'</a></p>';
	}

	return $more;
}
add_filter( 'excerpt_more', 'droidpress_excerpt_more' );

/**
 * Modifies the default body classes as per the theme's design.
 *
 * @param  array $classes The default body classes.
 * @return array          The modified body classes.
 */
function droidpress_body_class( $classes ) {
	if ( ! is_active_sidebar( 'sidebar' ) ) {
		$classes[] = 'sidebar-layout-none';
	}

	return $classes;
}
add_filter( 'body_class', 'droidpress_body_class' );

/**
 * Structure for comment form.
 *
 * @param  string $comment The comment list.
 * @param  array  $args    The argument.
 * @param  string $depth   The levels for comment.
 */
function droidpress_custom_comment_list( $comment, $args, $depth ) {
	if ( 'div' === $args['style'] ) {
		$tag       = 'div';
		$add_below = 'comment';
	} else {
		$tag       = 'li';
		$add_below = 'div-comment';
	} ?>
	<<?php echo esc_html( $tag ); ?> <?php comment_class( empty( $args['has_children'] ) ? '' : 'parent' ); ?> id="comment-<?php comment_ID(); ?>">
	<?php
	if ( 'div' !== $args['style'] ) {
		?>
		<div id="div-comment-<?php comment_ID(); ?>" class="comment-body">
			<?php
	}
	?>
	<div class="row">
		<div class="col-md-2 col-sm-2 col-xs-12 comment-author vcard droidpress-cmt-author-img">
			<?php
			if ( 0 !== $args['avatar_size'] ) {
				echo get_avatar( $comment, $args['avatar_size'] );
			}
			?>
		</div>
		<div class="col-md-10 col-sm-10 col-xs-12">

			<div class="comment-author vcard droidpress-cmt-author-meta">
				<span class="comment-meta commentmetadata droidpress-cmt-date">
					<a href="<?php echo esc_html( htmlspecialchars( get_comment_link( $comment->comment_ID ) ) ); ?>">
					<?php
					/* translators: 1: date, 2: time */
					printf( wp_kses_post( 'Posted on %s' ), esc_html( get_comment_date( 'j F Y' ) ), esc_html( get_comment_time() ) );
					?>
				</a><?php edit_comment_link( __( '( Edit )', 'droidpress' ), '  ', '' ); ?>
				</span>
			</div>

			<?php
			if ( '0' === $comment->comment_approved ) {
				?>
				<em class="comment-awaiting-moderation"><?php esc_html_e( 'Your comment is awaiting moderation.', 'droidpress' ); ?>
				</em>
				<br/>
				<?php
			}
			?>

			<div class="droidpress-cmt-content"> <?php comment_text(); ?> </div>

			<div class="reply droidpress-cmt-reply">
				<?php
				comment_reply_link(
					array_merge(
						$args,
						array(
							'add_below' => $add_below,
							'depth'     => $depth,
							'max_depth' => $args['max_depth'],
						)
					)
				);
				?>
			</div>
		</div>
	</div>
	<?php
	if ( 'div' !== $args['style'] ) {
		?>
		</div>
		<?php
	}
}
