<?php
/**
 * Theme tags
 *
 * @package droidpress
 * @since 3.0.0
 */

/**
 * Outputs the post's published & modified date.
 *
 * @return void
 */
function droidpress_the_date() {
	$time_string = '<time class="published updated" datetime="%1$s">%2$s</time>';
	if ( get_the_time( 'U' ) !== get_the_modified_time( 'U' ) ) {
		$time_string = '<time class="entry-date published updated" datetime="%1$s">%2$s</time><time class="entry-date updated" datetime="%3$s">%4$s</time>';
	}

	$time_string = sprintf(
		$time_string,
		esc_attr( get_the_date( DATE_W3C ) ),
		esc_html( get_the_date() ),
		esc_attr( get_the_modified_date( DATE_W3C ) ),
		esc_html( get_the_modified_date() )
	);

	echo '<a href="' . esc_url( get_permalink() ) . '" rel="bookmark">' . $time_string . '</a>'; // WPCS: XSS ok.
}

/**
 * Outputs the author posts link.
 *
 * @return void
 */
function droidpress_the_author_link() {
	echo '<a class="url fn n" href="' . esc_url( get_author_posts_url( get_the_author_meta( 'ID' ) ) ) . '">' . esc_html( get_the_author() ) . '</a>';
}

/**
 * Outputs a visible or hidden class for an element. This class can be used to
 * hide or show a meta element using customizer.
 *
 * @param  string $setting The customizer setting.
 * @return void
 */
function droidpress_the_meta_visible_class( $setting ) {
	echo esc_attr( get_theme_mod( $setting ) ? 'hidden' : 'visible' );
}
